<?php
/*
 * This file contains various common function for the jupload plugin
 */

if (!defined('IN_COPPERMINE')) { die('Not in Coppermine...');}
if (!defined('JUPLOAD_PHP')) { die('Not in Jupload...');}

$juploadRootDirectory = 'plugins/jupload/';
 
//####################################################################################################
//##############################  PARAMETER DEFINITION ###############################################
//####################################################################################################

//These texts will be both displayed on the screen, and written in the configuration file.
//See also the jupload/page/config_page.php file

/*
 * $JUploadParamList is an array of param. Each param contains the following keys:
 * name: the parameter name. It's the key that'll be stored in the $JUPLOAD_CONFIG array.
 * desc: an explanation about the parameter. Only in english. This explanation will only be visible to admins.
 * default: The default value for this parameter.
 * type: the data type for this parameter. Can be 'int' or 'string'. Any unknown value is managed as a string.
 */

$JUploadParamList = array (
	array (
		'name' => 'alwaysVisible',
		'desc' => <<<EOS
If set to a non 0 value, the JUpload link will always be visible, whenever the user may or may not upload pictures. 
If the user clicks on it, here is what happens:<BR>
<DIR>
<LI>1- If the user may upload pictures, the upload page containing the applet opens,
<LI>2- If the user is authenticated, but may not upload pictures, an error message is displayed,
<LI>3- If the user is not authenticated, an error page containing a link to the login page is displayed. Once 
connected, the user is redirected to the upload page. We go back to step 1, above.
</DIR>
If set to 0, the JUpload link will only be displayed if the user may upload pictures
EOS
,
		'default' => '0',
		'type' => 'int'
	),
	array (
		'name' => 'highQualityPreview',
		'desc' => <<<EOS
If set to a non 0 value, the JUpload will disply better preview icons. But pictures will then display slower 
within the applet. <BR>
The pictures sent to the server are always of the best available quality, whatever is the value of this parameter.<BR>
EOS
,
		'default' => '1',
		'type' => 'int'
	)
); 

//####################################################################################################
//#################################    FUNCTIONS    ##################################################
//####################################################################################################


//####################################################################################################
//##############################     LOCAL CODE     ##################################################
//####################################################################################################

//Localisation. Handled from specific files, to make upgrade of coppermine easier:
//First: we load the default text (english)
require($juploadRootDirectory . 'lang/english.php');

//Then, you overload with the choosen language, for existing translations.
//$bJuploadTranslactionExist is used later, in page_upload.php, to display a message indicating that
//the translation for the current language doesn't exist ... and to give the link to the page where all
//the text to translate is written (part of text is in the applet, not in the php code).

$defaultLang = $CONFIG['lang'];
if (isset($USER['lang'])) {
	$defaultLang = $USER[lang];
}
$defaultLangFile = $juploadRootDirectory . 'lang/' . $defaultLang . '.php';


$bJuploadTranslactionExist = file_exists($defaultLangFile);

if ($defaultLang == 'english'  ||  $defaultLang == 'english_gb') {
	//We already included (required) the jupload english.php file
	$bJuploadTranslactionExist = true;  //Was not true for english_gb, one line before ...   ;-)
} else if ($bJuploadTranslactionExist) {
    include($defaultLangFile);
}
//Let's call any user specific constant, like overriding of the 'standard' translation texts.
include($juploadRootDirectory . 'user/user.inc.php');




/////////////////////////////////////////////////////////////////////////////////////////////////
//Let's load the config file, or use default values, for non defined variables.
include($juploadRootDirectory . 'user/config.inc.php');
foreach($JUploadParamList as $param) {
	if (!isset($JUPLOAD_CONFIG[$param['name']])) {
		$JUPLOAD_CONFIG[$param['name']] = $param['default'];
	}	
}//foreach($JUploadParamList)
